| Title: | Skew Boxplot Geoms for 'ggplot2' |
|---|---|
| Description: | Provides 'ggplot2' extensions for creating skewed boxplots using several statistical methods (Kimber, 1990 <doi:10.2307/2347808>; Hubert and Vandervieren, 2008 <doi:10.1016/j.csda.2007.11.008>; Adil et al., 2015 <doi:10.18187/pjsor.v11i1.500>; Babura et al., 2017 <doi:10.1063/1.4982872>; Walker et al., 2018 <doi:10.1080/00031305.2018.1448891>). The package implements custom statistical transformations and geometries to visualize data distributions with an emphasis on skewness. |
| Authors: | Mustafa Cavus [aut, cre] (ORCID: <https://orcid.org/0000-0002-6172-5449>) |
| Maintainer: | Mustafa Cavus <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.0.0 |
| Built: | 2026-05-13 06:51:09 UTC |
| Source: | https://github.com/cran/ggskewboxplots |
Compute alternative boxplot statistics
compute_skew_stats(x, method = "tukey", k = 1.5)compute_skew_stats(x, method = "tukey", k = 1.5)
x |
A numeric vector |
method |
Method name ("tukey", "kimber", "hubert", etc.) |
k |
Tuning parameter (default 1.5) |
A list of boxplot stats: ymin, lower, middle, upper, ymax, outliers
Draws boxplots using alternative methods for skewness adjustment.
geom_skewboxplot( mapping = NULL, data = NULL, stat = StatSkewBoxplot, position = "dodge", ..., method = "tukey", k = 1.5, na.rm = FALSE, show.legend = NA, inherit.aes = TRUE )geom_skewboxplot( mapping = NULL, data = NULL, stat = StatSkewBoxplot, position = "dodge", ..., method = "tukey", k = 1.5, na.rm = FALSE, show.legend = NA, inherit.aes = TRUE )
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
stat |
The statistical transformation to use on the data for this layer. Defaults to "skewboxplot". |
position |
A position adjustment to use on the data for this layer. This
can be used in various ways, including to prevent overplotting and
improving the display. The
|
... |
Other arguments passed on to
|
method |
Skew boxplot method (e.g. "tukey", "hubert", etc.) |
k |
Tuning parameter (default = 1.5) |
na.rm |
If |
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
A ggplot2 layer object that can be added to a ggplot.
Summarise skewness-aware boxplot statistics
summarise_skewbox(.data, var, method = "tukey", k = 1.5)summarise_skewbox(.data, var, method = "tukey", k = 1.5)
.data |
A data frame (preferably grouped) |
var |
Unquoted numeric column name |
method |
Method name (e.g. "adil", "hubert", etc.) |
k |
Tuning parameter (default 1.5) |
A tibble with boxplot stats